==> sdd.debin-jar-0.2.20-sources.jar: ar/com/sdd/debin/io/VendedorRecurrenciaListaVendedorResponse.java <==
package ar.com.sdd.debin.io;

import ar.com.sdd.debin.entity.Recurrencia;
import ar.com.sdd.debin.entity.Respuesta;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

import java.util.Arrays;
import java.util.Collection;

@JsonIgnoreProperties(ignoreUnknown = true)
@JsonInclude(JsonInclude.Include.NON_NULL)
public class VendedorRecurrenciaListaVendedorResponse {

    private Respuesta respuesta;
    private Collection<Recurrencia> recurrencia;

    public VendedorRecurrenciaListaVendedorResponse() {
    }

    public Respuesta getRespuesta() {
        return respuesta;
    }

    public void setRespuesta(Respuesta respuesta) {
        this.respuesta = respuesta;
    }

    public Collection<Recurrencia> getRecurrencia() {
        return recurrencia;
    }

    public void setRecurrencia(Collection<Recurrencia> recurrencia) {
        this.recurrencia = recurrencia;
    }

    @Override
    public String toString() {
        return "VendedorRecurrenciaListaVendedorResponse ["
                + ((respuesta != null) ? "respuesta=" + respuesta + ", " : "")
                + ((recurrencia != null) ? "recurrencia=" + Arrays.toString(recurrencia.toArray()) : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        VendedorRecurrenciaListaVendedorResponse that = (VendedorRecurrenciaListaVendedorResponse) o;

        if (respuesta != null ? !respuesta.equals(that.respuesta) : that.respuesta != null) return false;
        return recurrencia != null ? recurrencia.equals(that.recurrencia) : that.recurrencia == null;
    }

    @Override
    public int hashCode() {
        int result = respuesta != null ? respuesta.hashCode() : 0;
        result = 31 * result + (recurrencia != null ? recurrencia.hashCode() : 0);
        return result;
    }
}

==> sdd.debin-jar-0.2.21-sources.jar: ar/com/sdd/debin/io/VendedorRecurrenciaListaVendedorResponse.java <==
package ar.com.sdd.debin.io;

import ar.com.sdd.debin.entity.Recurrencia;
import ar.com.sdd.debin.entity.Respuesta;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import javax.json.bind.annotation.JsonbNillable;

import java.util.Arrays;
import java.util.Collection;

@JsonIgnoreProperties(ignoreUnknown = true)
@JsonbNillable
public class VendedorRecurrenciaListaVendedorResponse {

    private Respuesta respuesta;
    private Collection<Recurrencia> recurrencia;

    public VendedorRecurrenciaListaVendedorResponse() {
    }

    public Respuesta getRespuesta() {
        return respuesta;
    }

    public void setRespuesta(Respuesta respuesta) {
        this.respuesta = respuesta;
    }

    public Collection<Recurrencia> getRecurrencia() {
        return recurrencia;
    }

    public void setRecurrencia(Collection<Recurrencia> recurrencia) {
        this.recurrencia = recurrencia;
    }

    @Override
    public String toString() {
        return "VendedorRecurrenciaListaVendedorResponse ["
                + ((respuesta != null) ? "respuesta=" + respuesta + ", " : "")
                + ((recurrencia != null) ? "recurrencia=" + Arrays.toString(recurrencia.toArray()) : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        VendedorRecurrenciaListaVendedorResponse that = (VendedorRecurrenciaListaVendedorResponse) o;

        if (respuesta != null ? !respuesta.equals(that.respuesta) : that.respuesta != null) return false;
        return recurrencia != null ? recurrencia.equals(that.recurrencia) : that.recurrencia == null;
    }

    @Override
    public int hashCode() {
        int result = respuesta != null ? respuesta.hashCode() : 0;
        result = 31 * result + (recurrencia != null ? recurrencia.hashCode() : 0);
        return result;
    }
}
